summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorHong Shi <hongsh@codeaurora.org>2016-09-27 11:22:38 +0800
committerGerrit - the friendly Code Review server <code-review@localhost>2016-11-18 16:43:17 -0800
commitcaacbad1b10041856620c07812235e02a6e7bc98 (patch)
tree0d3e7a09d5ebc4be1a5f044d6edbcedf4586964f
parentf2e20ef2f99f04b8a586c994bcfc426d94377938 (diff)
qcacld-3.0: Fix roaming fresh assoc issue in mcc
qcacld-2.0 to qcacld-3.0 propagation Roaming send fresh assoc instead of reassoc because the preauth frame has high possibility sending on wrong channel if in MCC. Need to trigger scan to schedule to target AP channel if DUT in MCC state. Change-Id: Ifee8bc00c10ea995093e3f4621b94e0d81a7c32e CRs-Fixed: 962162
-rw-r--r--core/mac/src/pe/lim/lim_ft_preauth.c11
1 files changed, 8 insertions, 3 deletions
diff --git a/core/mac/src/pe/lim/lim_ft_preauth.c b/core/mac/src/pe/lim/lim_ft_preauth.c
index 42c9d386d521..920874c13772 100644
--- a/core/mac/src/pe/lim/lim_ft_preauth.c
+++ b/core/mac/src/pe/lim/lim_ft_preauth.c
@@ -31,6 +31,7 @@
#include <lim_prop_exts_utils.h>
#include <lim_assoc_utils.h>
#include <lim_session.h>
+#include <lim_session_utils.h>
#include <lim_admit_control.h>
#include "wma.h"
@@ -191,9 +192,13 @@ int lim_process_ft_pre_auth_req(tpAniSirGlobal mac_ctx, tpSirMsgQ msg)
session, 0, 0);
#endif
- /* Dont need to suspend if APs are in same channel */
- if (session->currentOperChannel !=
- session->ftPEContext.pFTPreAuthReq->preAuthchannelNum) {
+ /*
+ * Dont need to suspend if APs are in same channel and DUT
+ * is not in MCC state
+ */
+ if ((session->currentOperChannel !=
+ session->ftPEContext.pFTPreAuthReq->preAuthchannelNum)
+ || lim_is_in_mcc(mac_ctx)) {
/* Need to suspend link only if the channels are different */
lim_log(mac_ctx, LOG2,
FL("Performing pre-auth on diff channel(session %p)"),